<template>
  <div class="app-container">
    <el-form
      :model="queryParams"
      ref="queryForm"
      size="small"
      :inline="true"
      v-show="showSearch"
      label-width="68px"
    >
      <el-form-item label="姓名" prop="name">
        <el-input
          v-model="queryParams.name"
          placeholder="请输入姓名"
          clearable
          @keyup.enter.native="handleQuery"
        />
      </el-form-item>
      <el-form-item label="手机号" prop="phone">
        <el-input
          v-model="queryParams.phone"
          placeholder="请输入手机号"
          clearable
          @keyup.enter.native="handleQuery"
        />
      </el-form-item>
      <el-form-item>
        <el-button
          type="primary"
          icon="el-icon-search"
          size="mini"
          @click="handleQuery"
          >搜索</el-button
        >
        <el-button icon="el-icon-refresh" size="mini" @click="resetQuery"
          >重置</el-button
        >
      </el-form-item>
    </el-form>

    <el-row :gutter="10" class="mb8">
      <el-col :span="1.5">
        <el-button
          type="primary"
          icon="el-icon-refresh"
          size="mini"
          @click="handleExport"
          :disabled="single"
          v-hasPermi="['hosp:harmType:export']"
          >恢复
        </el-button>
      </el-col>
    </el-row>

    <el-table
      v-loading="loading"
      :data="harmTypeList"
      @selection-change="handleSelectionChange"
      border
    >
      <el-table-column type="selection" width="55" align="center" />
      <el-table-column label="编码" align="center" prop="cusId" />
      <el-table-column label="姓名" align="center" prop="cusName" />
      <el-table-column label="性别" align="center" prop="cusSex">
        <template slot-scope="scope">
          <dict-tag :options="dict.type.sys_user_sex" :value="scope.row.cusSex" />
        </template>
      </el-table-column>
      <el-table-column label="电话号码" align="center" prop="cusPhone" />
      <el-table-column label="工作单位" align="center" prop="tjCompName" />
      <el-table-column label="创建人" align="center" prop="createBy" />
      <el-table-column label="创建时间" align="center" prop="createTime" />
    </el-table>

    <div class="pag">
      <div class="pag1">
        <pagination
          v-show="total > 0"
          :total="total"
          :page.sync="queryParams.page"
          :limit.sync="queryParams.pageSize"
          @pagination="getList"
        />
      </div>
    </div>
  </div>
</template>
  
  <script>
import { getCustomerBlack, putCustomerBlack } from "@/api/system/blacklist";

export default {
  dicts: ["sys_user_sex"],
  name: "Blacklist",
  data() {
    let checkPhoneNum = (rule, value, callback) => {
      console.log(value);
      let patter = new RegExp(/^1\s*[3456789]\s*(\d\s*){9}$/);
      if (value == "" && value == undefined && !value) {
        return callback("");
      } else if (value != undefined && value != "") {
        return callback();
      } else if (!patter.test(value)) {
        return callback("");
      }
    };
    return {
      // 遮罩层
      loading: false,
      // 选中数组
      ids: [],
      // 非单个禁用
      single: true,
      // 非多个禁用
      multiple: true,
      // 显示搜索条件
      showSearch: true,
      // 总条数
      total: 0,
      // 职业病表格数据
      harmTypeList: [],
      selectionList: [],
      // 弹出层标题
      title: "",
      // 是否显示弹出层
      open: false,
      // 查询参数
      queryParams: {
        page: 1,
        pageSize: 10,
        name: null,
        phone: null,
      },
      // 表单参数
      form: {},
      // 表单校验
      rules: {
        harmPinYin: [
          { required: true, validator: checkPhoneNum, trigger: "blur" },
        ],

        harmType: [
          { required: true, validator: checkPhoneNum, trigger: "blur" },
        ],

        protection: [
          { required: true, validator: checkPhoneNum, trigger: "blur" },
        ],
      },
    };
  },
  created() {
    this.getList();
  },
  methods: {
    getList() {
      this.loading = true
      getCustomerBlack(this.queryParams).then((res) => {
        this.harmTypeList = res.data.records;
        this.total = res.data.total
        this.loading = false
      });
    },

    // 表单重置
    reset() {
      this.form = {
        aid: null,
        harmpinyin: null,
        harmtype: null,
        sort: null,
        harminfo: null,
        externalcode: null,
        harmcode: null,
        type: null,
        protection: null,
      };
      this.resetForm("form");
    },
    /** 搜索按钮操作 */
    handleQuery() {
      this.queryParams.page = 1;
      this.getList();
    },
    /** 重置按钮操作 */
    resetQuery() {
      this.resetForm("queryForm");
      this.handleQuery();
    },
    // 多选框选中数据
    handleSelectionChange(selection) {
      this.selectionList = selection;
      this.ids = [];
      this.ids = selection.map((item) => item.aid);
      this.single = selection.length !== 1;
      this.multiple = !selection.length;
    },

    handleAdd() {},

    SelectionChange(selection) {},

    /** 导出按钮操作 */
    handleExport() {
      console.log(this.selectionList);
      let data = {
        days: -1,
        cusId: this.selectionList[0].cusId,
        id: this.selectionList[0].id,
      };
      putCustomerBlack(data).then((res) => {
        this.$modal.msgSuccess("已移出黑名单");
        this.getList();
      });
    },
  },
};
</script>
  
  
  <style>
.pag {
  width: 100%;
  display: flex;
  justify-content: center;
}

.pag1 {
  width: 30%;
}
</style>
  